# Solana/SPL Token/Epilogue

While writing this chapter, a sudden spark of creativity ignited within me. I started to wonder: Is learning Solana solely on a local devnet really the best way? Should we try doing something on the Solana mainnet instead? This way, my readers and I could collaborate on a shared learning journey. You'd be able to check the blockchain history, see what I've done in the past, and also observe what others, like yourself, are doing. There's nothing better than that!

**After months of intense writing, Solana has convinced me that ordinary people can tell their own stories through tokens.**

My next phase will take place on the Solana mainnet. I plan to introduce readers to how to run a token project on the mainnet: including token issuance, creating liquidity pools, and conducting token airdrops. I want these tokens to be more than just vessels for memes, but symbols of learning. The airdrop for educational tokens will be based on a "proof of study" and any reader who has worked through this tutorial and hands-on experiments will be able to generate a proof of study and apply for an airdrop of tokens. This process will be automated. Whenever someone holds one of these tokens, it will say: "I've explored the world of Solana. I've studied this tutorial. I am part of this ecosystem." This token will shine brightly in your wallet.

- The proof of study will not be issued by me, instead, you will generate it yourself.
- You can trade the airdropped tokens like any other meme coin.
- The educational tokens can be minted indefinitely, ensuring they hold only symbolic value.
